summaryrefslogtreecommitdiffhomepage
path: root/pkg/sentry/fs/gofer/fs.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/sentry/fs/gofer/fs.go')
-rw-r--r--pkg/sentry/fs/gofer/fs.go14
1 files changed, 8 insertions, 6 deletions
diff --git a/pkg/sentry/fs/gofer/fs.go b/pkg/sentry/fs/gofer/fs.go
index ed30cb1f1..2dc000c6f 100644
--- a/pkg/sentry/fs/gofer/fs.go
+++ b/pkg/sentry/fs/gofer/fs.go
@@ -75,11 +75,11 @@ var (
// ErrNoTransport is returned when there is no 'trans' option.
ErrNoTransport = errors.New("missing required option: 'trans='")
- // ErrNoReadFD is returned when there is no 'rfdno' option.
- ErrNoReadFD = errors.New("missing required option: 'rfdno='")
+ // ErrFileNoReadFD is returned when there is no 'rfdno' option.
+ ErrFileNoReadFD = errors.New("missing required option: 'rfdno='")
- // ErrNoWriteFD is returned when there is no 'wfdno' option.
- ErrNoWriteFD = errors.New("missing required option: 'wfdno='")
+ // ErrFileNoWriteFD is returned when there is no 'wfdno' option.
+ ErrFileNoWriteFD = errors.New("missing required option: 'wfdno='")
)
// filesystem is a 9p client.
@@ -87,6 +87,8 @@ var (
// +stateify savable
type filesystem struct{}
+var _ fs.Filesystem = (*filesystem)(nil)
+
func init() {
fs.RegisterFilesystem(&filesystem{})
}
@@ -160,14 +162,14 @@ func options(data string) (opts, error) {
// Check for the required 'rfdno=' option.
srfd, ok := options[readFDKey]
if !ok {
- return o, ErrNoReadFD
+ return o, ErrFileNoReadFD
}
delete(options, readFDKey)
// Check for the required 'wfdno=' option.
swfd, ok := options[writeFDKey]
if !ok {
- return o, ErrNoWriteFD
+ return o, ErrFileNoWriteFD
}
delete(options, writeFDKey)